@@ -1,19 +1,12 @@
 #![deny(rust_2018_idioms)]
-#![deny(broken_intra_doc_links)]
 
 use proc_macro::TokenStream;
 use proc_macro2::Span;
 use quote::quote;
-use syn::{
-    parse::{Error, Parse, ParseStream, Result},
-    parse_macro_input,
-    parse_quote,
-    punctuated::Punctuated,
-    spanned::Spanned,
-    Ident,
-    Lit,
-    Token,
-};
+use syn::parse::{Error, Parse, ParseStream, Result};
+use syn::punctuated::Punctuated;
+use syn::spanned::Spanned;
+use syn::{parse_macro_input, parse_quote, Ident, Lit, Token};
 
 pub(crate) mod attributes;
 pub(crate) mod consts;
@@ -101,10 +94,10 @@ macro_rules! match_options {
 pub fn command(attr: TokenStream, input: TokenStream) -> TokenStream {
     let mut fun = parse_macro_input!(input as CommandFun);
 
-    let _name = if !attr.is_empty() {
-        parse_macro_input!(attr as Lit).to_str()
-    } else {
+    let _name = if attr.is_empty() {
         fun.name.to_string_non_raw()
+    } else {
+        parse_macro_input!(attr as Lit).to_str()
     };
 
     let mut options = Options::new();
@@ -173,7 +166,7 @@ pub fn command(attr: TokenStream, input: TokenStream) -> TokenStream {
     propagate_err!(create_declaration_validations(&mut fun, DeclarFor::Command));
 
     let res = parse_quote!(serenity::framework::standard::CommandResult);
-    create_return_type_validation(&mut fun, res);
+    create_return_type_validation(&mut fun, &res);
 
     let visibility = fun.visibility;
     let name = fun.name.clone();
@@ -272,7 +265,7 @@ pub fn command(attr: TokenStream, input: TokenStream) -> TokenStream {
 /// | `#[wrong_channel(s)]` </br> `#[wrong_channel = s]`                                                                                            | If a user is using the help-command in a channel where a command is not available, this behaviour will be executed.                                                                                                                              | `s` is a string. Accepts `strike` (strikethroughs), `hide` (will not be listed) or `nothing`(leave be).    |
 /// | `#[embed_error_colour(n)]`                                                                                                                    | Colour that the help-embed will use upon an error.                                                                                                                                                                                               | `n` is a name to one of the provided constants of the `Colour` struct or an RGB value `#RRGGBB`.           |
 /// | `#[embed_success_colour(n)]`                                                                                                                  | Colour that the help-embed will use normally.                                                                                                                                                                                                    | `n` is a name to one of the provided constants of the `Colour` struct or an RGB value `#RRGGBB`.           |
-/// | `#[max_levenshtein_distance(n)]`                                                                                                              | How much should the help command search for a similiar name.</br> Indicator for a nested guild. The prefix will be repeated based on what kind of level the item sits. A sub-group would be level two, a sub-sub-group would be level three.     | `n` is a 64-bit, unsigned integer.                                                                         |
+/// | `#[max_levenshtein_distance(n)]`                                                                                                              | How much should the help command search for a similar name.</br> Indicator for a nested guild. The prefix will be repeated based on what kind of level the item sits. A sub-group would be level two, a sub-sub-group would be level three.     | `n` is a 64-bit, unsigned integer.                                                                         |
 /// | `#[indention_prefix(s)]` </br> `#[indention_prefix = s]`                                                                                      | The prefix used to express how deeply nested a command or group is.                                                                                                                                                                              | `s` is a string                                                                                            |
 ///
 /// [`command`]: macro@command
@@ -280,7 +273,9 @@ pub fn command(attr: TokenStream, input: TokenStream) -> TokenStream {
 pub fn help(attr: TokenStream, input: TokenStream) -> TokenStream {
     let mut fun = parse_macro_input!(input as CommandFun);
 
-    let names = if !attr.is_empty() {
+    let names = if attr.is_empty() {
+        vec!["help".to_string()]
+    } else {
         struct Names(Vec<String>);
 
         impl Parse for Names {
@@ -292,8 +287,6 @@ pub fn help(attr: TokenStream, input: TokenStream) -> TokenStream {
         let Names(names) = parse_macro_input!(attr as Names);
 
         names
-    } else {
-        vec!["help".to_string()]
     };
 
     // Revert the change for the names of documentation attributes done when
@@ -458,7 +451,7 @@ pub fn help(attr: TokenStream, input: TokenStream) -> TokenStream {
     propagate_err!(create_declaration_validations(&mut fun, DeclarFor::Help));
 
     let res = parse_quote!(serenity::framework::standard::CommandResult);
-    create_return_type_validation(&mut fun, res);
+    create_return_type_validation(&mut fun, &res);
 
     let options = fun.name.with_suffix(HELP_OPTIONS);
 
@@ -619,10 +612,10 @@ pub fn help(attr: TokenStream, input: TokenStream) -> TokenStream {
 pub fn group(attr: TokenStream, input: TokenStream) -> TokenStream {
     let group = parse_macro_input!(input as GroupStruct);
 
-    let name = if !attr.is_empty() {
-        parse_macro_input!(attr as Lit).to_str()
-    } else {
+    let name = if attr.is_empty() {
         group.name.to_string_non_raw()
+    } else {
+        parse_macro_input!(attr as Lit).to_str()
     };
 
     let mut options = GroupOptions::new();
@@ -773,7 +766,7 @@ pub fn check(_attr: TokenStream, input: TokenStream) -> TokenStream {
     propagate_err!(create_declaration_validations(&mut fun, DeclarFor::Check));
 
     let res = parse_quote!(std::result::Result<(), serenity::framework::standard::Reason>);
-    create_return_type_validation(&mut fun, res);
+    create_return_type_validation(&mut fun, &res);
 
     let n = fun.name.clone();
     let n2 = name.clone();
