@@ -1,13 +1,12 @@
 use std::str::FromStr;
 
-use proc_macro2::Span;
-use proc_macro2::TokenStream as TokenStream2;
+use proc_macro2::{Span, TokenStream as TokenStream2};
 use quote::{quote, ToTokens};
+use syn::parse::{Error, Parse, ParseStream, Result};
+use syn::punctuated::Punctuated;
+use syn::spanned::Spanned;
 use syn::{
     braced,
-    parse::{Error, Parse, ParseStream, Result},
-    punctuated::Punctuated,
-    spanned::Spanned,
     Attribute,
     Block,
     Expr,
@@ -237,7 +236,7 @@ pub struct ClosureHook {
 
 #[derive(Debug)]
 pub enum Hook {
-    Function(FunctionHook),
+    Function(Box<FunctionHook>),
     Closure(ClosureHook),
 }
 
@@ -247,7 +246,7 @@ impl Parse for Hook {
         let cooked = remove_cooked(&mut attributes);
 
         if is_function(input) {
-            parse_function_hook(input, attributes, cooked).map(Self::Function)
+            parse_function_hook(input, attributes, cooked).map(|h| Self::Function(Box::new(h)))
         } else {
             parse_closure_hook(input, attributes, cooked).map(Self::Closure)
         }
@@ -352,7 +351,7 @@ impl Permissions {
             "MANAGE_NICKNAMES" => 0b0000_1000_0000_0000_0000_0000_0000_0000,
             "MANAGE_ROLES" => 0b0001_0000_0000_0000_0000_0000_0000_0000,
             "MANAGE_WEBHOOKS" => 0b0010_0000_0000_0000_0000_0000_0000_0000,
-            "MANAGE_EMOJIS" => 0b0100_0000_0000_0000_0000_0000_0000_0000,
+            "MANAGE_EMOJIS_AND_STICKERS" => 0b0100_0000_0000_0000_0000_0000_0000_0000,
             _ => return None,
         }))
     }
@@ -362,10 +361,10 @@ impl ToTokens for Permissions {
     fn to_tokens(&self, stream: &mut TokenStream2) {
         let bits = self.0;
 
-        let path = quote!(serenity::model::permissions::Permissions);
+        let path = quote!(serenity::model::permissions::Permissions::from_bits_truncate);
 
         stream.extend(quote! {
-            #path { bits: #bits }
+            #path(#bits)
         });
     }
 }
